@@ -67,6 +67,9 @@ def detectOutliers(frame: pd.DataFrame, options: dict):
             stdev = data.std()
             avg = data.mean()
             
+            # fix for near zero stdev
+            stdev = max(abs(avg)**0.5, stdev)
+            
             if val > avg + mult * stdev:
                     frame['X_OUTLIER'][index] = 1
             else:
@@ -76,6 +79,17 @@ def detectOutliers(frame: pd.DataFrame, options: dict):
     
     return(frame)
 
+def calcContributions(x, model, options):
+    '''
+    Calculate the regression coeff * predictor value for all columns (to calc contribution
+    of each variable on the final regression output)
+    '''
+    try:
+        vals = x[options['predictorColumns']] * model.coef_
+        return ','.join(map(str, vals))
+    except:
+        return None
+
 def predict(frame: pd.DataFrame, options: dict) -> dict:
     """
     The function takes as an argument the "frame" parameter, which is a 
@@ -125,7 +139,12 @@ def predict(frame: pd.DataFrame, options: dict) -> dict:
     
     xscore = frame[options['predictorColumns']]
     yhat = model.predict(xscore)
-    
+        
+    frame['X_RSQR'] = model.score(x, y)
+    frame['X_INTERCEPT'] = model.intercept_
+    frame['X_PREDICTORS'] = ','.join(options['predictorColumns'])
+    frame['X_COEFFICIENTS'] = ','.join(map(str, model.coef_))
+    frame['X_VAR_CONTRIBUTIONS'] = frame.apply(lambda x: calcContributions(x, model, options), axis = 1)
     frame['X_PREDICTED'] = yhat
 
     fdict['frame'] = frame
@@ -184,7 +203,7 @@ if __name__ == '__main__':
     print("Usage: python -m src.Ridge [json options] [csv source data] [output csv file]")
     print("-------------------------------")
 
-    DEBUG = True
+    DEBUG = False
     
     if DEBUG:
         fileName = 'c:/temp/iris_with_role_and_split.csv'
